package jekyll-format

  1. Overview
  2. Docs

Module Jekyll_format.ESource

These are error strings returned by the parser. They are primarily used by the test cases to pattern match on failures and are not for general use.

Sourceval yaml_no_start : string
Sourceval yaml_no_end : string
Sourceval yaml_field_parse : string -> string